@@ -3,7 +3,7 @@ package Make;
 use strict;
 use warnings;
 
-our $VERSION = '2.004';
+our $VERSION = '2.005';
 
 use Carp qw(confess croak);
 use Config;
@@ -68,9 +68,17 @@ sub target {
 
 sub has_target {
     my ( $self, $target ) = @_;
+    confess "Trying to has_target undef value" unless defined $target;
     return exists $self->{Depend}{$target};
 }
 
+sub targets {
+    my ($self) = @_;
+    ## no critic ( BuiltinFunctions::RequireBlockGrep )
+    return grep !/%|^\./, keys %{ $self->{Depend} };
+    ## use critic
+}
+
 # Utility routine for patching %.o type 'patterns'
 my %pattern_cache;
 
@@ -718,7 +726,13 @@ Find or create L<Make::Target> for given target-name.
 
 =head2 has_target
 
-Find L<Make::Target> for given target-name, or undef.
+Returns boolean on whether the given target-name is known to this object.
+
+=head2 targets
+
+List all "real" (non-dot, non-inference) target-names known to this object
+at the time called, unsorted. Note this might change when C<Make> is
+called, as targets will be added as part of the dependency-search process.
 
 =head2 patrule
 
